@@ -1290,18 +1290,44 @@ BOOL sCommand_expand_env(sCommand* command, sObject* fun, sObject* nextin, sObje
     for(i=0; i < command->mArgsNum; i++) {
         /// options ///
         if(command->mArgs[i][0] == PARSER_MAGIC_NUMBER_OPTION) {
-            if(external_command) {
-                char* arg = MALLOC(strlen(command->mArgs[i]) + 1);
-                arg[0] = '-';
-                strcpy(arg + 1, command->mArgs[i] + 1);
-                sCommand_add_arg_to_command2(command, MANAGED arg);
+            if(command->mArgsEnv[i]) {
+                char* expanded_str;
+                BOOL expand_double_dollar;
+                if(!expand_env_to_command(ALLOC &expanded_str, command->mArgs[i], command, runinfo, nextin, &expand_double_dollar)) {
+                    return FALSE;
+                }
+
+                if(expand_double_dollar) {
+                    err_msg("invalid expanding varibale block", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                    FREE(expanded_str);
+                    return FALSE;
+                }
+
+                expanded_str[0] = '-';
+
+                if(external_command) {
+                    sCommand_add_arg_to_command2(command, MANAGED expanded_str);
+                }
+                else {
+                    if(!get_option(MANAGED expanded_str, command, fun, nextin, nextout, runinfo, &i)) {
+                        return FALSE;
+                    }
+                }
             }
             else {
-                char* arg = MALLOC(strlen(command->mArgs[i]) + 1);
-                arg[0] = '-';
-                strcpy(arg + 1, command->mArgs[i] + 1);
-                if(!get_option(MANAGED arg, command, fun, nextin, nextout, runinfo, &i)) {
-                    return FALSE;
+                if(external_command) {
+                    char* arg = MALLOC(strlen(command->mArgs[i]) + 1);
+                    arg[0] = '-';
+                    strcpy(arg + 1, command->mArgs[i] + 1);
+                    sCommand_add_arg_to_command2(command, MANAGED arg);
+                }
+                else {
+                    char* arg = MALLOC(strlen(command->mArgs[i]) + 1);
+                    arg[0] = '-';
+                    strcpy(arg + 1, command->mArgs[i] + 1);
+                    if(!get_option(MANAGED arg, command, fun, nextin, nextout, runinfo, &i)) {
+                        return FALSE;
+                    }
                 }
             }
         }
