@@ -127,9 +127,11 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         fd_split(nextin, lf);
 
         if(vector_count(SFD(nextin).fdbuf.mLines) > 0) {
-            msave_screen();
             msave_ttysettings();
-            minitscr();
+            msave_screen();
+            initscr();
+            raw();
+            keypad(stdscr, TRUE);
 
             const int maxx = mgetmaxx();
             const int maxy = mgetmaxy();
@@ -171,24 +173,23 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
             while(1) {
                 /// view ///
-                mclear();
+                clear();
                 int n = scrolltop;
                 int y = 0;
                 while(y < maxy && n < vector_count(SFD(nextin).fdbuf.mLines)) {
                     int attrs = 0;
                     if(n == cursor) {
-                        attrs |= kCAReverse;
+                        attrs = A_REVERSE;
                     }
                     else if(markfiles[n]) {
-                        attrs |= kCACyan;
-                        attrs |= kCABold;
+                        attrs = A_BOLD;
                     }
-                    if(attrs) mattron(attrs);
+                    if(attrs) attron(attrs);
 
                     char* line = vector_item(SFD(nextin).fdbuf.mLines, n);
 
                     if(str_termlen(code, line) <= maxx) {
-                        mmvprintw(y, 0, "%s", line);
+                        mvprintw(y, 0, "%s", line);
                         y++;
                     }
                     else {
@@ -196,24 +197,21 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         while(p < line + strlen(line)) {
                             char one_line[BUFSIZ];
                             str_cut(code, p, maxx, one_line, BUFSIZ);
-                            mmvprintw(y, 0, "%s", one_line);
+                            mvprintw(y, 0, "%s", one_line);
                             y++;
 
                             p+=strlen(one_line);
                         }
                     }
 
-                    if(attrs) {
-                        mattroff();
-                    }
+                    if(attrs) attroff(attrs);
 
                     n++;
                 }
-                mrefresh();
+                refresh();
 
                 /// input ///
-                int meta;
-                int key = mgetch(&meta);
+                int key = getch();
 
                 if(key == 14 || key == KEY_DOWN) {
                     cursor++;
@@ -228,11 +226,12 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     cursor -= (maxy /2);
                 }
                 else if(key == 12) {
-                    mclear();
-                    mrefresh();
+                    clear();
+                    refresh();
                 }
-                else if(key == 'q' || key == 3 | key == 27 || key == 7) {
-                    mendwin();
+                else if(key == 'q' || key == 3 || key == 7) {
+                    err_msg("canceled", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                    endwin();
                     mrestore_screen();
                     mrestore_ttysettings();
                     FREE(markfiles);
@@ -324,7 +323,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
             FREE(markfiles);
 
-            mendwin();
+            endwin();
             mrestore_screen();
             mrestore_ttysettings();
         }
@@ -378,21 +377,29 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         while(p - SFD(nextin).fdbuf.mBuf < SFD(nextin).fdbuf.mBufLen) {
             if(*p == '\n') {
                 if(!fd_writec(nextin2, *p)) {
+                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                    runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
                 p++;
             }
             else if(*p >= 0 && *p <= 31) {
                 if(!fd_writec(nextin2, '^')) {
+                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                    runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
                 if(!fd_writec(nextin2, *p+'@')) {
+                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                    runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
                 p++;
             }
             else {
                 if(!fd_writec(nextin2, *p)) {
+                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                    runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                     return FALSE;
                 }
                 p++;
@@ -404,7 +411,9 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
         msave_ttysettings();
         msave_screen();
-        minitscr();
+        initscr();
+        raw();
+        keypad(stdscr, TRUE);
 
         const int maxx = mgetmaxx();
         const int maxy = mgetmaxy();
@@ -446,24 +455,23 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
         while(1) {
             /// view ///
-            mclear();
+            clear();
             int n = scrolltop;
             int y = 0;
             while(y < maxy && n < vector_count(SFD(nextin2).fdbuf.mLines)) {
                 int attrs = 0;
                 if(n == cursor) {
-                    attrs |= kCAReverse;
+                    attrs = A_REVERSE;
                 }
                 else if(markfiles[n]) {
-                    attrs |= kCACyan;
-                    attrs |= kCABold;
+                    attrs = A_BOLD;
                 }
-                if(attrs) mattron(attrs);
+                if(attrs) attron(attrs);
 
                 char* line = vector_item(SFD(nextin2).fdbuf.mLines, n);
 
                 if(str_termlen(code, line) <= maxx) {
-                    mmvprintw(y, 0, "%s", line);
+                    mvprintw(y, 0, "%s", line);
                     y++;
                 }
                 else {
@@ -471,24 +479,21 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     while(p < line + strlen(line)) {
                         char one_line[BUFSIZ];
                         str_cut(code, p, maxx, one_line, BUFSIZ);
-                        mmvprintw(y, 0, "%s", one_line);
+                        mvprintw(y, 0, "%s", one_line);
                         y++;
 
                         p+=strlen(one_line);
                     }
                 }
 
-                if(attrs) {
-                    mattroff();
-                }
+                if(attrs) attroff(attrs);
 
                 n++;
             }
-            mrefresh();
+            refresh();
 
             /// input ///
-            int meta;
-            int key = mgetch(&meta);
+            int key = getch();
 
             if(key == 14 || key == KEY_DOWN) {
                 cursor++;
@@ -503,12 +508,12 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 cursor -= (maxy /2);
             }
             else if(key == 12) {
-                mclear();
-                mrefresh();
+                clear();
+                refresh();
             }
-            else if(key == 'q' || key == 3 | key == 27 || key == 7) {
+            else if(key == 'q' || key == 3 || key == 7) {
                 err_msg("p: canceled", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
-                mendwin();
+                endwin();
                 mrestore_screen();
                 mrestore_ttysettings();
                 FREE(markfiles);
@@ -560,7 +565,7 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
         FREE(markfiles);
 
-        mendwin();
+        endwin();
         mrestore_screen();
         mrestore_ttysettings();
     }
@@ -596,10 +601,12 @@ BOOL cmd_readline(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     char* buf = readline(prompt);
 
-    if(!fd_write(nextout, buf, strlen(buf))) {
-        err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
-        runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
-        return FALSE;
+    if(buf) {
+        if(!fd_write(nextout, buf, strlen(buf))) {
+            err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+            runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+            return FALSE;
+        }
     }
     
     runinfo->mRCode = 0;
@@ -960,7 +967,9 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(vector_count(v) > 0) {
         msave_ttysettings();       // 端末の設定の保存
         msave_screen();
-        minitscr();
+        initscr();
+        raw();
+        keypad(stdscr, TRUE);
 
         const int maxx = mgetmaxx();
         const int maxy = mgetmaxy();
@@ -968,8 +977,8 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         int cursor = 0;
         while(1) {
             /// 描写 ///
-            mclear();
-            mmvprintw(0,0,"%s", current_dir);
+            clear();
+            mvprintw(0,0,"%s", current_dir);
 
             int page = cursor/((maxy-1)*4);
             int n = page*4*(maxy-1);
@@ -978,13 +987,12 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
                 int attrs = 0;
                 if(n == cursor) {
-                    attrs |= kCAReverse;
+                    attrs |= A_REVERSE;
                 }
                 if(S_ISDIR(file->mStat.st_mode)) {
-                    attrs |= kCACyan;
-                    attrs |= kCABold;
+                    attrs |= A_BOLD;
                 }
-                if(attrs) mattron(attrs);
+                if(attrs) attron(attrs);
 
                 char file2[PATH_MAX];
                 str_cut2(kUtf8, string_c_str(file->mName), maxx/4-2, file2, PATH_MAX);
@@ -1008,21 +1016,18 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 }
 
                 if(marked) 
-                    mmvprintw(y, x, "*%s", file2);
+                    mvprintw(y, x, "*%s", file2);
                 else
-                    mmvprintw(y, x, " %s", file2);
+                    mvprintw(y, x, " %s", file2);
 
-                if(attrs) {
-                    mattroff();
-                }
+                if(attrs) attroff(attrs);
 
                 n++;
             }
-            mrefresh();
+            refresh();
 
             /// インプット ///
-            int meta;
-            int key = mgetch(&meta);
+            int key = getch();
 
             if(key == 14 || key == KEY_DOWN) {
                 cursor+=4;
@@ -1043,8 +1048,8 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 cursor -= (maxy-1)*4;
             }
             else if(key == 12) {
-                mclear();
-                mrefresh();
+                clear();
+                refresh();
             }
             else if(key == ' ' && multiple) {
                 sFile* cursor_file = vector_item(v, cursor);
@@ -1090,9 +1095,9 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             else if(key == '\t' || key == 'w') {
                 break;
             }
-            else if(key == 'q' || key == 3 | key == 27 || key == 7) {
+            else if(key == 'q' || key == 3 || key == 7) {
                 err_msg("canceled", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
-                mendwin();
+                endwin();
                 mrestore_screen();
                 mrestore_ttysettings();    // 端末の設定の復帰
                 int i;
@@ -1151,9 +1156,9 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
         }
 
-//mclear();
-//mrefresh();
-        mendwin();
+//clear();
+//refresh();
+        endwin();
         mrestore_screen();
         mrestore_ttysettings();    // 端末の設定の復帰
 
