@@ -2022,7 +2022,7 @@ BOOL cmd_rows(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         code = kEucjp;
     }
 
-    if(runinfo->mFilter && command->mArgsNumRuntime > 1 && command->mBlocksNum == command->mArgsNumRuntime-1) {
+    if(runinfo->mFilter && command->mArgsNumRuntime > 1 && command->mBlocksNum <= command->mArgsNumRuntime-1) {
         if(SFD(nextin).fdbuf.mBufLen == 0) {
             runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
         }
@@ -2087,9 +2087,14 @@ BOOL cmd_rows(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
                         int k;
                         for(k=0; k<kanjilen; k++) {
-                            const int size = ((*p & 0x80) >> 7) + ((*p & 0x40) >> 6) + ((*p & 0x20) >> 5) + ((*p & 0x10) >> 4);
                             array[k] = p;
-                            p+=size;
+                            if(((unsigned char)*p) > 127) {
+                                const int size = ((*p & 0x80) >> 7) + ((*p & 0x40) >> 6) + ((*p & 0x20) >> 5) + ((*p & 0x10) >> 4);
+                                p+=size;
+                            }
+                            else {
+                                p++;
+                            }
                         }
                         array[k] = p;
                     }
@@ -2112,20 +2117,32 @@ BOOL cmd_rows(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         for(j=first; j<=second; j++) {
                             fd_clear(nextin2);
 
-                            if(!fd_write(nextin2, array[j], array[j+1]-array[j])) {
+                            if(!fd_write(nextin2, array[j], array[j+1] -array[j])) {
                                 err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                                 runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                                 FREE(array);
                                 return FALSE;
                             }
 
-                            int rcode = 0;
-                            if(!run(command->mBlocks[i-1], nextin2, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+                            if(i-1 < command->mBlocksNum) {
+                                int rcode = 0;
+                                if(!run(command->mBlocks[i-1], nextin2, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+                                    runinfo->mRCode = rcode;
+                                    FREE(array);
+                                    return FALSE;
+                                }
                                 runinfo->mRCode = rcode;
-                                FREE(array);
-                                return FALSE;
                             }
-                            runinfo->mRCode = rcode;
+                            else {
+                                if(!fd_write(nextout, SFD(nextin2).fdbuf.mBuf, SFD(nextin2).fdbuf.mBufLen)) 
+                                {
+                                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                                    runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                                    FREE(array);
+                                    return FALSE;
+                                }
+                                runinfo->mRCode = 0;
+                            }
                         }
                     }
                     else {
@@ -2142,13 +2159,25 @@ BOOL cmd_rows(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                                 return FALSE;
                             }
 
-                            int rcode = 0;
-                            if(!run(command->mBlocks[i-1], nextin2, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+                            if(i-1 < command->mBlocksNum) {
+                                int rcode = 0;
+                                if(!run(command->mBlocks[i-1], nextin2, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+                                    runinfo->mRCode = rcode;
+                                    FREE(array);
+                                    return FALSE;
+                                }
                                 runinfo->mRCode = rcode;
-                                FREE(array);
-                                return FALSE;
                             }
-                            runinfo->mRCode = rcode;
+                            else {
+                                if(!fd_write(nextout, SFD(nextin2).fdbuf.mBuf, SFD(nextin2).fdbuf.mBufLen)) 
+                                {
+                                    err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                                    runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                                    FREE(array);
+                                    return FALSE;
+                                }
+                                runinfo->mRCode = 0;
+                            }
                         }
                     }
 
@@ -2178,12 +2207,23 @@ BOOL cmd_rows(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     return FALSE;
                 }
 
-                int rcode = 0;
-                if(!run(command->mBlocks[i-1], nextin2, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+                if(i-1 < command->mBlocksNum) {
+                    int rcode = 0;
+                    if(!run(command->mBlocks[i-1], nextin2, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
+                        runinfo->mRCode = rcode;
+                        return FALSE;
+                    }
                     runinfo->mRCode = rcode;
-                    return FALSE;
                 }
-                runinfo->mRCode = rcode;
+                else {
+                    if(!fd_write(nextout, SFD(nextin2).fdbuf.mBuf, SFD(nextin2).fdbuf.mBufLen)) 
+                    {
+                        err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                        runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                        return FALSE;
+                    }
+                    runinfo->mRCode = 0;
+                }
             }
         }
     }
