@@ -287,15 +287,6 @@ static int mark()
     gxyzshObject->mFlg |= GC_MARK;
     count += uobject_gc_children_mark(gxyzshObject);
 
-/*
-    /// mark objects in pipe ///
-    list_it* it;
-    for(it=list_begin(gPipes); it; it=list_next(it)) {
-        mark_objects_in_pipe(list_item(it));
-    }
-    count += mark_objects_in_pipe(gGlobalPipe);
-*/
-
     return count;
 }
 
