@@ -296,6 +296,11 @@ static BOOL read_one_argument(char** p, sBuf* buf, char* sname, int* sline, BOOL
                 err_msg("close single quote or double quote", sname, *sline, buf->mBuf);
                 return FALSE;
             }
+            else if(dquote && **p == '\\') {
+                if(!read_quote(p, buf, sname, sline)) {
+                    return FALSE;
+                }
+            }
             else if(**p == '\n') {
                 (*sline)++;
                 add_char_to_buf(buf, **p);
@@ -377,6 +382,10 @@ static BOOL read_one_argument(char** p, sBuf* buf, char* sname, int* sline, BOOL
                         return FALSE;
                     }
                 }
+                else if(gxyzshSigInt) {
+                    err_msg("signal interrupt", sname, *sline, "here document");
+                    return FALSE;
+                }
                 else if(**p == '\n') {
                     add_char_to_buf(buf, **p);
                     (*p)++;
