@@ -4,6 +4,7 @@
 #include <stdio.h>
 #include <signal.h>
 #include <sys/stat.h>
+#include <locale.h>
 #include <fcntl.h>
 
 sObject* gErrMsg;
@@ -112,9 +113,11 @@ static void xyzsh_read_rc()
 
 void xyzsh_init(enum eAppType app_type, BOOL no_runtime_script)
 {
-    setenv("XYZSH_VERSION", "1.2.5", 1);
+    setenv("XYZSH_VERSION", "1.2.6", 1);
     setenv("XYZSH_DATAROOTDIR", DATAROOTDIR, 1);
 
+    setlocale(LC_ALL, "");
+
     stack_init(1);;
     stack_start_stack();
 
